.. _evaluation:


Evaluation
**********

.. currentmodule:: torchkge.evaluation

Dissimilarities
---------------
.. automodule:: torchkge.evaluation.Dissimilarities
    :members:

LinkPrediction
--------------
.. automodule:: torchkge.evaluation.LinkPrediction

.. autoclass:: torchkge.evaluation.LinkPrediction.LinkPredictionEvaluator
    :members:
